@@ -11,7 +11,7 @@ use Bible::OBML::HTML;
 use Bible::Reference 1.02;
 use Clone 'clone';
 
-our $VERSION = '1.13'; # VERSION
+our $VERSION = '1.14'; # VERSION
 
 has bible    => 'Protestant';
 has acronyms => 1;
@@ -311,7 +311,13 @@ sub render {
     $content =~ s/\s+\}/\}/g;
     $content =~ s/\[\s+/\[/g;
     $content =~ s/\s+\]/\]/g;
-    $content =~ s/(?<=\^)\s+(?=[\,\;\.\-\!\?]+\s)//g;
+    $content =~ s/\(\s+/\(/g;
+    $content =~ s/\s+\)/\)/g;
+
+    $content =~ s/(\s*(?:\[[^\]]*\]|\{[^\}]*\}))\s*([\,\;\.\!\?]+)/$2$1/g;
+    $content =~ s/\s+(?=[\,\;\.\!\?]+)//g;
+    $content =~ s/\s+(?=[\-]+\s)//g;
+
     $content =~ s/\s+$/\n/msg;
     $content .= "\n";
 
@@ -473,7 +479,7 @@ Bible::OBML - Open Bible Markup Language parser and renderer
 
 =head1 VERSION
 
-version 1.13
+version 1.14
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bible-OBML.svg)](https://travis-ci.org/gryphonshafer/Bible-OBML)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bible-OBML/badge.png)](https://coveralls.io/r/gryphonshafer/Bible-OBML)
